==> peperit_2.0_estable.zip: themes/peperit/html_files/componentes/plantilla/menus/menuCategoriasHamburguesa.php <==
<?php
	//Este menú tiene las categorías desplegables y un menú horizontal con otras opciones
	$tieneBlog = Theme::getConfigParam('hasBlog', false);
?>
<div class="megamenu col-md-3 col-sm-4 col-xs-6 dropdown">
	<div class="v-megamenu-<?=Theme::getConfigParam('container_style', 'container');?>" id="dropdownEscaparates" data-toggle="dropdown">
		<div class="v-megamenu-title"> 
			<?php /* <!--<span class="glyphicon glyphicon-align-justify font-w"></span><h3><?= traducir('Catálogo') ?></h3>
			  <span id="disparadorCatalogo" class="font-w glyphicon glyphicon-plus"></span>-->
			 * 
			 */ ?>
			<i class="icon-align-justify"></i><h3><?= traducir("Categorías"); ?></h3>
		</div>
	</div>
	<div class="v-megamenu dropdown-menu"  aria-labelledby="dropdownEscaparates">
		<ul>
			<?php
			$opcionesEscaparate = new OpcionesWidget(array(
				'nivel_maximo' => 3,
				'limite' => 8
			));
			$widget_lista_escaparates = new Widget($_WH->GW('lista_escaparates', 'menu_escaparates'), $opcionesEscaparate);
			?>
		</ul>
	</div>
</div>
<div class="header-megamenu col-xs-6 col-md-7 col-sm-5">
	<nav id="fieldmegamenu-main" class="fieldmegamenu inactive">
		<ul>
			<?php
			//Tenemos que indicar en la clase de la etiqueta "a" si es 'active' o no
			?>
			<li class="root">
				<a href="<?= Shop::$configuracion->url; ?>" class="" title="<?= traducir('Inicio'); ?>">
					<i class="mdi mdi-home"></i><span class="title-text"><?= traducir('Inicio'); ?></span>
				</a>
			</li>
			<li class="root">
				<a href="<?= Shop::$configuracion->url; ?>conocenos/" class="" title="<?= traducir('Quiénes somos'); ?>">
					<i class="mdi mdi-information-variant"></i><span class="title-text"><?= traducir('Quiénes somos'); ?></span>
				</a>
			</li>
			<li class="root">
				<a href="<?= Shop::$configuracion->url; ?>contacto/" class="" title="<?= traducir('Contáctanos'); ?>">
					<i class="mdi mdi-email"></i><span class="title-text"><?= traducir('Contacto'); ?></span>
				</a>
			</li>

			<?php
			if ($tieneBlog) {
				?>
				<li class="root">
					<a href="<?= Shop::$configuracion->url; ?>blog/events" class="" title="<?= traducir('Nuestras actividades'); ?>">
						<i class="mdi mdi-message"></i><span class="title-text"><?= traducir('Actividades'); ?></span>
					</a>
				</li>
				<?php
			}
			/*
			  <li class="root">
			  <div class="root-item no-description">
			  <a href="<?= Shop::$configuracion->url; ?>blog/" class="" title="<?= traducir('Blog'); ?>">
			  <div class="title title_font"><span class="title-text"><?= traducir('Blog'); ?></span></div>
			  </a>
			  </div>
			  </li>
			  <div class="stt-menu col-md-2 hidden-sm hidden-xs">
			  <div class="st_header">
			  <div class="st_img"><span class="glyphicon glyphicon-phone-alt"></span></div>
			  <div class="st_text title_font"><?= Shop::$empresa->telefono_empresa ?></div>
			  </div>
			  </div> */
			?>
		</ul>
	</nav>
</div>

==> peperit_2.1_estable.zip: themes/peperit/html_files/componentes/plantilla/menus/menuCategoriasHamburguesa.php <==
<?php
	//Este menú tiene las categorías desplegables y un menú horizontal con otras opciones
	$tieneBlog = Theme::getConfigParam('hasBlog', false);
        
        // TATIANA (11/08/20)
        //cambio del dropdown a collapse para que funcione mejor en el movil
?>
<div class="megamenu col-md-3 col-sm-4 col-xs-6 dropdown">
	<div class="v-megamenu-<?=Theme::getConfigParam('container_style', 'container');?> collapsed" data-toggle="collapse" data-target="#menuHamburguesa" aria-expanded="false">
		<div class="v-megamenu-title"> 
			<?php /* <!--<span class="glyphicon glyphicon-align-justify font-w"></span><h3><?= traducir('Catálogo') ?></h3>
			  <span id="disparadorCatalogo" class="font-w glyphicon glyphicon-plus"></span>-->
			 * 
			 */ ?>
			<i class="icon-align-justify"></i><h3><?= traducir("Categorías"); ?></h3>
		</div>
	</div>
	<div class="v-megamenu collapse" id="menuHamburguesa" >
                <ul>
			<?php
			$opcionesEscaparate = new OpcionesWidget(array(
				'nivel_maximo' => 3,
				'limite' => 8,
                                //'ficheroListaEscaparate' => 'cabListaEscaparateCollapse',
                                //'ficheroLineaEscaparate' => 'lineaEscaparateCollapse'
			));
			$widget_lista_escaparates = new Widget($_WH->GW('lista_escaparates', 'menu_escaparates'), $opcionesEscaparate);
			?>
                    
                        
		</ul>
	</div>
</div>
<div class="header-megamenu col-xs-6 col-md-7 col-sm-5">
	<nav id="fieldmegamenu-main" class="fieldmegamenu inactive">
		<ul>
			<?php
			//Tenemos que indicar en la clase de la etiqueta "a" si es 'active' o no
			?>
			<li class="root">
				<a href="<?= Shop::$configuracion->url; ?>" class="" title="<?= traducir('Inicio'); ?>">
					<i class="mdi mdi-home"></i><span class="title-text"><?= traducir('Inicio'); ?></span>
				</a>
			</li>
			<li class="root">
				<a href="<?= Shop::$configuracion->url; ?>conocenos/" class="" title="<?= traducir('Quiénes somos'); ?>">
					<i class="mdi mdi-information-variant"></i><span class="title-text"><?= traducir('Quiénes somos'); ?></span>
				</a>
			</li>
			<li class="root">
				<a href="<?= Shop::$configuracion->url; ?>contacto/" class="" title="<?= traducir('Contáctanos'); ?>">
					<i class="mdi mdi-email"></i><span class="title-text"><?= traducir('Contacto'); ?></span>
				</a>
			</li>

			<?php
			if ($tieneBlog) {
				?>
				<li class="root">
					<a href="<?= Shop::$configuracion->url; ?>blog/events" class="" title="<?= traducir('Nuestras actividades'); ?>">
						<i class="mdi mdi-message"></i><span class="title-text"><?= traducir('Actividades'); ?></span>
					</a>
				</li>
				<?php
			}
			/*
			  <li class="root">
			  <div class="root-item no-description">
			  <a href="<?= Shop::$configuracion->url; ?>blog/" class="" title="<?= traducir('Blog'); ?>">
			  <div class="title title_font"><span class="title-text"><?= traducir('Blog'); ?></span></div>
			  </a>
			  </div>
			  </li>
			  <div class="stt-menu col-md-2 hidden-sm hidden-xs">
			  <div class="st_header">
			  <div class="st_img"><span class="glyphicon glyphicon-phone-alt"></span></div>
			  <div class="st_text title_font"><?= Shop::$empresa->telefono_empresa ?></div>
			  </div>
			  </div> */
			?>
		</ul>
	</nav>
</div>
